@@ -1,6 +1,7 @@
 import pytest
 
 import os
+import platform
 import socket
 import shutil
 import signal
@@ -42,15 +43,21 @@ def curvezmq_client():
                               auth_config=auth_config,
                               database=":memory:")
 
+        # server.daemon = True
+
         client = SQLiteClient(connect_address="tcp://127.0.0.1:5002",
                               server_curve_id=server_key_id,
                               client_curve_id=client_key_id,
                               curve_dir=curve_dir,
                               use_encryption=True)
         server.start()
+        # server.join()
         LOG.info("Started Test SQLiteServer")
         yield client
-        os.kill(server.pid, signal.SIGINT)
+        if platform.system().lower() == 'windows':
+            os.system("taskkill  /F /pid "+str(server.pid))
+        else:
+            os.kill(server.pid, signal.SIGINT)
         server.join()
-        client.shutdown()
+        client.cleanup()
 
